@@ -3,8 +3,8 @@
 # Multiarch
 DEB_HOST_MULTIARCH=$(dpkg-architecture -qDEB_HOST_MULTIARCH)
 
-TEMP=$(getopt -l 'pyver:,srcdir:,builddir:,modules:' -- "$@")
-if $?; then
+TEMP=$(getopt -l 'destdir:,pyver:,srcdir:,builddir:,modules:' -- "$@")
+if "$?"; then
         echo 'Terminating...' >&2
         exit 1
 fi
@@ -16,6 +16,7 @@ unset TEMP
 
 while true; do
     case "$1" in
+        --destdir)  destdir="$2"                 ; shift 2 ;;
         --pyver)    pyver="$2"                   ; shift 2 ;;
         --srcdir)   srcdir=$(readlink -f "$2")   ; shift 2 ;;
         --builddir) builddir=$(readlink -f "$2") ; shift 2 ;;
@@ -28,17 +29,15 @@ while true; do
     esac
 done
 
-
 # build paths
-pybuilddir=$(pybuild --system custom -p "$pyver" --print "{build_dir}")
+pybuilddir=$(pybuild --name cctbx -s custom -p "$pyver" --print "{build_dir}")
 
 # install path's
 prefix=/usr
-destdir=$(pybuild --system custom -p "$pyver" --print "{destdir}")
 bindir=$prefix/bin
 pkglibdir=$prefix/lib/cctbx/python"$pyver"
 libdir=$prefix/lib/$DEB_HOST_MULTIARCH
-pythondir=$(pybuild --system custom -p "$pyver" --print "{install_dir}")
+pythondir=$(pybuild --name cctbx -s custom -p "$pyver" --print "{install_dir}")
 incdir=$prefix/include
 
 cd "$(dirname "${BASH_SOURCE[0]}")" || exit
@@ -47,15 +46,18 @@ echo "Intalling CCTBX into a FHS system"
 echo "Modules: $modules"
 echo ""
 echo "From the source $srcdir"
-echo "         build  $builddir"
+echo "     and build  $builddir"
 echo ""
 echo "To the FHS :"
+echo "         destdir    $destdir"
 echo "         pyver      $pyver"
 echo "         bindir     $bindir"
 echo "         incdir     $incdir"
 echo "         pkglibdir  $pkglibdir"
 echo "         libdir     $libdir"
 echo "         pythondir  $pythondir"
+echo ""
+echo "with PYTHONPATH $pybuilddir"
 
 #####################
 # install pkglibdir #
@@ -67,7 +69,7 @@ install -d "$destdir$pkglibdir"
 
 PYTHONPATH="$pybuilddir" LIBTBX_BUILD="$builddir" python"$pyver" update_libtbx_env.py --dest-dir="$destdir"
 
-# install test files
+# install generated test files
 
 cat <<EOF | rsync -avr --prune-empty-dirs --include-from="-" "$builddir"/ "$destdir$pkglibdir"
 + */
@@ -204,6 +206,8 @@ cat <<EOF | rsync -avr --prune-empty-dirs --include-from="-" "$srcdir"/ "$destdi
 + */
 - debian/***
 + annlib_adaptbx/tests/***
++ cctbx/regression/data/***
++ cctbx/regression/itvb_2001_table_a1427_hall_symbols.html
 + cma_es/cma/initials.par
 + fable/fem/major_types.hpp
 + fable/test/***
